gramex.pptgen package
=====================

Submodules
----------

gramex.pptgen.color module
--------------------------

.. automodule:: gramex.pptgen.color
   :members:
   :undoc-members:
   :show-inheritance:

gramex.pptgen.commands module
-----------------------------

.. automodule:: gramex.pptgen.commands
   :members:
   :undoc-members:
   :show-inheritance:

gramex.pptgen.fontwidth module
------------------------------

.. automodule:: gramex.pptgen.fontwidth
   :members:
   :undoc-members:
   :show-inheritance:

gramex.pptgen.utils module
--------------------------

.. automodule:: gramex.pptgen.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gramex.pptgen
   :members:
   :undoc-members:
   :show-inheritance:
